@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import List, Optional
 from px_settings.contrib.django import settings as s
 
 
@@ -9,6 +10,8 @@ __all__ = 'Settings', 'settings'
 @dataclass
 class Settings:
     AUTOLOAD_MODULE: str = 'access_scopes'
+    REGISTRIES: Optional[List[str]] = None
+    AGGREGATES: Optional[List[str]] = None
 
 
 settings = Settings()
