@@ -1,7 +1,10 @@
 from typing import List, Union
 
+from django.utils.translation import ugettext
+
 from ..scopes import ScopeRegistry
 from ..aggregates import Aggregate, Aggregates
+from ..utils import flatten_aggregates
 from .permissions import generate_permissions
 from .groups import generate_group
 
@@ -16,15 +19,7 @@ def generate_all(
     for registry in registries:
         generate_permissions(registry)
 
-    aggregates = (
-        a
-        for agg in aggregates
-        for a in (
-            (getattr(agg, name) for name in agg._item_names)
-            if isinstance(agg, type) and issubclass(agg, Aggregates)
-            else (agg,)
-        )
-    )
+    aggregates = flatten_aggregates(aggregates)
 
     for aggregate in aggregates:
         generate_group(aggregate)
